@@ -31,6 +31,7 @@ const (
 )
 
 const (
+	AddressSecretKey    = "address"
 	UsernameSecretKey   = "username"
 	PasswordSecretKey   = "password"
 	CACrtSecretKey      = "ca.crt"
@@ -40,6 +41,7 @@ const (
 	PublicKeySecretKey  = "identity.pub"
 	KnownHostsSecretKey = "known_hosts"
 	BearerTokenKey      = "bearerToken"
+	TrustPolicyKey      = "trustpolicy.json"
 
 	// Deprecated: Replaced by CACrtSecretKey, but kept for backwards
 	// compatibility with deprecated TLS flags.
@@ -70,16 +72,20 @@ type Options struct {
 	TargetPath          string
 	ManifestFile        string
 	BearerToken         string
+	VerificationCrts    []VerificationCrt
+	TrustPolicy         []byte
+	Address             string
 
-	// Deprecated: Replaced by CACrt, but kept for backwards compatibility
-	// with deprecated TLS flags.
-	CAFile []byte
-	// Deprecated: Replaced by TLSCrt, but kept for backwards compatibility
-	// with deprecated TLS flags.
-	CertFile []byte
-	// Deprecated: Replaced by TLSKey, but kept for backwards compatibility
-	// with deprecated TLS flags.
-	KeyFile []byte
+	// GitHub App options
+	GitHubAppID             string
+	GitHubAppInstallationID string
+	GitHubAppPrivateKey     string
+	GitHubAppBaseURL        string
+}
+
+type VerificationCrt struct {
+	Name  string
+	CACrt []byte
 }
 
 func MakeDefaultOptions() Options {
@@ -90,9 +96,6 @@ func MakeDefaultOptions() Options {
 		PrivateKeyAlgorithm: RSAPrivateKeyAlgorithm,
 		Username:            "",
 		Password:            "",
-		CAFile:              []byte{},
-		CertFile:            []byte{},
-		KeyFile:             []byte{},
 		ManifestFile:        "secret.yaml",
 		BearerToken:         "",
 	}
